// file: Exchange.h
// the Swarm room
// variables and methods for exchange class

#import <objectbase/SwarmObject.h>
#import <collections.h>

typedef struct trader{
  int status;
  id who;
} trader;

@interface Exchange: SwarmObject
{
  id traderSet;
  int excess;
  int balance;
  int tag;
}

-setTag: (int) t;
-(int) getTag;

-setExcess: (int) x;
-(int) getExcess;

-setBalance: (int) x;
-(int) getBalance;

-createEnd;
-addTrader: (id) a;
-setStatusFor: (id) a To: (int) x;
-changeStatusFor: (id) a By: (int) dx;
-removeTrader: (id) a;

-printStatus;

@end
